@@ -23,6 +23,9 @@ integers. The string value of an item will be the name that it was defined with
 in its set. New items can always be added to an enumeration.
 """
 
+from aeidon.i18n import _
+from aeidon.i18n import __
+
 __all__ = ("EnumerationItem", "Enumeration",)
 
 
@@ -47,6 +50,11 @@ class EnumerationItem(int):
         """For consistency, always return ``True``."""
         return True
 
+    def __getattribute__(self, name):
+        """Return attribute, evaluating any lazy translations."""
+        value = super().__getattribute__(name)
+        return _(value) if isinstance(value, __) else value
+
     def __str__(self):
         """Return name as the string representation."""
         return self.name
@@ -90,7 +98,7 @@ class Enumeration(list):
         for item in self:
             if getattr(item, name) == value:
                 return item
-        raise ValueError("Name {} not found".format(repr(name)))
+        raise ValueError("Name {!r} not found".format(name))
 
     def __setattr__(self, name, value):
         """Set value of enumeration item with correct attributes."""
