@@ -19,9 +19,10 @@
 
 import aeidon
 import os
+import shutil
 import sys
 
-from aeidon.i18n import _
+from aeidon.i18n import __
 
 __all__ = [
     "align_methods",
@@ -36,10 +37,10 @@ __all__ = [
 
 
 class AlignMethodNumber(aeidon.EnumerationItem):
-    label = _("Subtitle number")
+    label = __("Subtitle number")
 
 class AlignMethodPosition(aeidon.EnumerationItem):
-    label = _("Subtitle position")
+    label = __("Subtitle position")
 
 align_methods = aeidon.Enumeration()
 align_methods.NUMBER = AlignMethodNumber()
@@ -55,26 +56,46 @@ documents.TRAN = DocumentTranslation()
 
 
 class Framerate23976(aeidon.EnumerationItem):
-    label = _("23.976 fps")
+    label = __("23.976 fps")
     value = 24 / 1.001
 
 class Framerate24000(aeidon.EnumerationItem):
-    label = _("24.000 fps")
+    label = __("24.000 fps")
     value = 24.0
 
 class Framerate25000(aeidon.EnumerationItem):
-    label = _("25.000 fps")
+    label = __("25.000 fps")
     value = 25.0
 
 class Framerate29970(aeidon.EnumerationItem):
-    label = _("29.970 fps")
+    label = __("29.970 fps")
     value = 30 / 1.001
 
+class Framerate30000(aeidon.EnumerationItem):
+    label = __("30.000 fps")
+    value = 30.0
+
+class Framerate50000(aeidon.EnumerationItem):
+    label = __("50.000 fps")
+    value = 50.0
+
+class Framerate59940(aeidon.EnumerationItem):
+    label = __("59.940 fps")
+    value = 60 / 1.001
+
+class Framerate60000(aeidon.EnumerationItem):
+    label = __("60.000 fps")
+    value = 60.0
+
 framerates = aeidon.Enumeration()
 framerates.FPS_23_976 = Framerate23976()
 framerates.FPS_24_000 = Framerate24000()
 framerates.FPS_25_000 = Framerate25000()
 framerates.FPS_29_970 = Framerate29970()
+framerates.FPS_30_000 = Framerate30000()
+framerates.FPS_50_000 = Framerate50000()
+framerates.FPS_59_940 = Framerate59940()
+framerates.FPS_60_000 = Framerate60000()
 
 
 class ModeTime(aeidon.EnumerationItem): pass
@@ -88,7 +109,7 @@ modes.SECONDS = ModeSeconds()
 
 
 class NewlinesMac(aeidon.EnumerationItem):
-    label = _("Mac (classic)")
+    label = __("Mac (classic)")
     value = "\r"
 
 class NewlinesUnix(aeidon.EnumerationItem):
@@ -140,7 +161,7 @@ class PlayerMPlayer(aeidon.EnumerationItem):
     if sys.platform != "win32":
         # Required for mplayer to work if gaupol was started
         # as a background process (&) from a terminal window.
-        # http://www.mplayerhq.hu/DOCS/HTML/en/faq.html#idp11051520
+        # http://www.mplayerhq.hu/DOCS/HTML/en/faq.html#idm5930
         command = "{} < /dev/null".format(command)
 
     command_utf_8 = " ".join((_get_mplayer_executable(),
@@ -156,9 +177,11 @@ class PlayerMPlayer(aeidon.EnumerationItem):
     if sys.platform != "win32":
         # Required for mplayer to work if gaupol was started
         # as a background process (&) from a terminal window.
-        # http://www.mplayerhq.hu/DOCS/HTML/en/faq.html#idp11051520
+        # http://www.mplayerhq.hu/DOCS/HTML/en/faq.html#idm5930
         command_utf_8 = "{} < /dev/null".format(command_utf_8)
 
+    executable = _get_mplayer_executable()
+    found = shutil.which(_get_mplayer_executable()) is not None
     label = "MPlayer"
 
 class PlayerMPV(aeidon.EnumerationItem):
@@ -176,9 +199,11 @@ class PlayerMPV(aeidon.EnumerationItem):
                               "--hr-seek=yes",
                               "--start=$SECONDS",
                               "--sub-file=$SUBFILE",
-                              "--sub-codepage=utf-8:utf-8-broken",
+                              "--sub-codepage=utf-8",
                               "$VIDEOFILE",))
 
+    executable = _get_mpv_executable()
+    found = shutil.which(_get_mpv_executable()) is not None
     label = "mpv"
 
 class PlayerVLC(aeidon.EnumerationItem):
@@ -193,6 +218,8 @@ class PlayerVLC(aeidon.EnumerationItem):
                               ":sub-file=$SUBFILE",
                               ":subsdec-encoding=UTF-8",))
 
+    executable = _get_vlc_executable()
+    found = shutil.which(_get_vlc_executable()) is not None
     label = "VLC"
 
 players = aeidon.Enumeration()
